import { EditorItemIdGenerator } from "@fern-api/editor-item-id-generator";
import { TransactionGenerator } from "@fern-api/transaction-generator";
import { FernApiEditor } from "@fern-fern/api-editor-sdk";
import { MockDefinitionItem } from "./MockDefinitionItem";
import { MockEndpoint } from "./MockEndpoint";
import { MockError } from "./MockError";
import { MockType } from "./MockType";
export class MockPackage extends MockDefinitionItem {
    packageId;
    packageName;
    constructor({ name = "Mock Package", ...superInit }) {
        super(superInit);
        this.packageId = EditorItemIdGenerator.package();
        this.packageName = name;
    }
    addPackage(name) {
        const package_ = new MockPackage({
            name,
            applyTransaction: this.applyTransaction.bind(this),
        });
        this.applyTransaction(TransactionGenerator.createPackage({
            packageId: package_.packageId,
            packageName: package_.packageName,
            parent: this.packageId,
        }));
        return package_;
    }
    addEndpoint(name) {
        const endpoint = new MockEndpoint({
            name,
            applyTransaction: this.applyTransaction.bind(this),
        });
        this.applyTransaction(TransactionGenerator.createEndpoint({
            parent: this.packageId,
            endpointId: endpoint.endpointId,
            endpointName: endpoint.endpointName,
        }));
        return endpoint;
    }
    addType({ name, shape } = {}) {
        const type = new MockType({
            name,
            shape,
            applyTransaction: this.applyTransaction.bind(this),
        });
        this.applyTransaction(TransactionGenerator.createType({
            parent: this.packageId,
            typeId: type.typeId,
            typeName: type.typeName,
            shape: type.shape,
        }));
        return type;
    }
    addObject({ name, shape = { properties: [], extensions: [] }, } = {}) {
        return this.addType({ name, shape: FernApiEditor.Shape.object(shape) });
    }
    addUnion({ name, shape = { discriminant: "type", members: [] }, } = {}) {
        return this.addType({ name, shape: FernApiEditor.Shape.union(shape) });
    }
    addError(name) {
        const error = new MockError({
            name,
            applyTransaction: this.applyTransaction.bind(this),
        });
        this.applyTransaction(TransactionGenerator.createError({
            parent: this.packageId,
            errorId: error.errorId,
            errorName: error.errorName,
        }));
        return error;
    }
}
